# Caddo Benchmark Tool

This repository contains files for Caddo Benchmark.

## 🔌 How to run?

#### Install via pip

```
user@computer:~$ pip install caddo-tool
```

#### Implement all benchmark functions and run from command line
```
user@computer:~$ caddo_tool
```

## 📓 Any documentation?

Yes, check wiki...
